@@ -8,29 +8,32 @@
 from __future__ import print_function
 import argparse
 import sys
+import math
 from datetime import datetime, timedelta
 from itertools import zip_longest
 from colorama import init
+import os
+import re
 
-VERSION = '0.3.1'
+VERSION = "0.4.0"
 
 init()
 
 # ANSI escape SGR Parameters color codes
 AVAILABLE_COLORS = {
-    'red': 91,
-    'blue': 94,
-    'green': 92,
-    'magenta': 95,
-    'yellow': 93,
-    'black': 90,
-    'cyan': 96
+    "red": 91,
+    "blue": 94,
+    "green": 92,
+    "magenta": 95,
+    "yellow": 93,
+    "black": 90,
+    "cyan": 96,
 }
 
-DAYS = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
-DELIM = ','
-TICK = '▇'
-SM_TICK = '▏'
+DAYS = ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"]
+DELIM = ","
+TICK = "▇"
+SM_TICK = "▏"
 
 try:
     range = xrange
@@ -40,98 +43,58 @@ except NameError:
 
 def init_args():
     """Parse and return the arguments."""
-    parser = argparse.ArgumentParser(
-        description='draw basic graphs on terminal')
+    parser = argparse.ArgumentParser(description="draw basic graphs on terminal")
     parser.add_argument(
-        'filename',
-        nargs='?',
+        "filename",
+        nargs="?",
         default="-",
-        help='data file name (comma or space separated). Defaults to stdin.')
+        help="data file name (comma or space separated). Defaults to stdin.",
+    )
+    parser.add_argument("--title", help="Title of graph")
     parser.add_argument(
-        '--title',
-        help='Title of graph'
+        "--width", type=int, default=50, help="width of graph in characters default:50"
+    )
+    parser.add_argument("--format", default="{:<5.2f}", help="format specifier to use.")
+    parser.add_argument(
+        "--suffix", default="", help="string to add as a suffix to all data points."
     )
     parser.add_argument(
-        '--width',
-        type=int,
-        default=50,
-        help='width of graph in characters default:50'
+        "--no-labels", action="store_true", help="Do not print the label column"
     )
     parser.add_argument(
-        '--format',
-        default='{:<5.2f}',
-        help='format specifier to use.'
+        "--no-values", action="store_true", help="Do not print the values at end"
+    )
+    parser.add_argument("--color", nargs="*", help="Graph bar color( s )")
+    parser.add_argument("--vertical", action="store_true", help="Vertical graph")
+    parser.add_argument("--stacked", action="store_true", help="Stacked bar graph")
+    parser.add_argument("--histogram", action="store_true", help="Histogram")
+    parser.add_argument("--bins", default=5, type=int, help="Bins of Histogram")
+    parser.add_argument(
+        "--different-scale",
+        action="store_true",
+        help="Categories have different scales.",
     )
     parser.add_argument(
-        '--suffix',
-        default='',
-        help='string to add as a suffix to all data points.'
+        "--calendar", action="store_true", help="Calendar Heatmap chart"
+    )
+    parser.add_argument("--start-dt", help="Start date for Calendar chart")
+    parser.add_argument(
+        "--custom-tick", default="", help="Custom tick mark, emoji approved"
     )
     parser.add_argument(
-        '--no-labels',
-        action='store_true',
-        help='Do not print the label column'
+        "--delim", default="", help="Custom delimiter, default , or space"
     )
     parser.add_argument(
-        '--no-values',
-        action='store_true',
-        help='Do not print the values at end'
+        "--verbose", action="store_true", help="Verbose output, helpful for debugging"
     )
     parser.add_argument(
-        '--color',
-        nargs='*',
-        choices=AVAILABLE_COLORS,
-        help='Graph bar color( s )'
-    )
-    parser.add_argument(
-        '--vertical',
-        action='store_true',
-        help='Vertical graph'
-    )
-    parser.add_argument(
-        '--stacked',
-        action='store_true',
-        help='Stacked bar graph'
-    )
-    parser.add_argument(
-        '--different-scale',
-        action='store_true',
-        help='Categories have different scales.'
-    )
-    parser.add_argument(
-        '--calendar',
-        action='store_true',
-        help='Calendar Heatmap chart'
-    )
-    parser.add_argument(
-        '--start-dt',
-        help='Start date for Calendar chart'
-    )
-    parser.add_argument(
-        '--custom-tick',
-        default='',
-        help='Custom tick mark, emoji approved'
-    )
-    parser.add_argument(
-        '--delim',
-        default='',
-        help='Custom delimiter, default , or space'
-    )
-    parser.add_argument(
-        '--verbose',
-        action='store_true',
-        help='Verbose output, helpful for debugging'
-    )
-    parser.add_argument(
-        '--label-before',
-        action='store_true',
+        "--label-before",
+        action="store_true",
         default=False,
-        help='Display the values before the bars'
+        help="Display the values before the bars",
     )
     parser.add_argument(
-        '--version',
-        action='store_true',
-        help='Display version and exit'
+        "--version", action="store_true", help="Display version and exit"
     )
     if len(sys.argv) == 1:
         if sys.stdin.isatty():
@@ -140,14 +103,14 @@ def init_args():
 
     args = vars(parser.parse_args())
 
-    if args['custom_tick'] != '':
+    if args["custom_tick"] != "":
         global TICK, SM_TICK
-        TICK = args['custom_tick']
-        SM_TICK = ''
+        TICK = args["custom_tick"]
+        SM_TICK = ""
 
-    if args['delim'] != '':
+    if args["delim"] != "":
         global DELIM
-        DELIM = args['delim']
+        DELIM = args["delim"]
 
     return args
 
@@ -156,12 +119,12 @@ def main():
     """Main function."""
     args = init_args()
 
-    if args['version']:
-        print('termgraph v{}'.format(VERSION))
+    if args["version"]:
+        print("termgraph v{}".format(VERSION))
         sys.exit()
 
     _, labels, data, colors = read_data(args)
-    if args['calendar']:
+    if args["calendar"]:
         calendar_heatmap(data, labels, args)
     else:
         chart(colors, data, args, labels)
@@ -218,22 +181,82 @@ def normalize(data, width):
     return normal_dat
 
 
+def hist_rows(data, args, colors):
+    """Prepare the Histgram graph.
+       Each row is printed through the print_row function."""
+
+    val_min = find_min(data)
+    val_max = find_max(data)
+
+    # Calculate borders
+    class_min = math.floor(val_min)
+    class_max = math.ceil(val_max)
+    class_range = class_max - class_min
+    class_width = class_range / args["bins"]
+
+    border = class_min
+    borders = []
+    max_len = len(str(border))
+
+    for b in range(args["bins"] + 1):
+        borders.append(border)
+        len_border = len(str(border))
+        if len_border > max_len:
+            max_len = len_border
+        border += class_width
+        border = round(border, 1)
+
+    # Count num of data via border
+    count_list = []
+
+    for start, end in zip(borders[:-1], borders[1:]):
+        count = 0
+        #        for d in [d]
+        for v in [row[0] for row in data]:
+            if start <= v < end:
+                count += 1
+
+        count_list.append([count])
+
+    normal_counts = normalize(count_list, args["width"])
+
+    for i, border in enumerate(zip(borders[:-1], borders[1:])):
+        if colors:
+            color = colors[0]
+        else:
+            color = None
+
+        if not args.get("no_labels"):
+            print("{:{x}} – {:{x}}: ".format(border[0], border[1], x=max_len), end="")
+
+        num_blocks = normal_counts[i]
+
+        yield (count_list[i][0], int(num_blocks[0]), 0, color)
+
+        if args.get("no_values"):
+            tail = ""
+        else:
+            tail = " {}{}".format(
+                args["format"].format(count_list[i][0]), args["suffix"]
+            )
+        print(tail)
+
+
 def horiz_rows(labels, data, normal_dat, args, colors, doprint=True):
     """Prepare the horizontal graph.
        Each row is printed through the print_row function."""
     val_min = find_min(data)
 
     for i in range(len(labels)):
-        if args['no_labels']:
+        if args["no_labels"]:
             # Hide the labels.
-            label = ''
+            label = ""
         else:
-            if args.get('label_before'):
+            if args.get("label_before"):
                 fmt = "{:<{x}}"
             else:
                 fmt = "{:<{x}}: "
-            label = fmt.format(labels[i],
-                               x=find_max_label_length(labels))
+            label = fmt.format(labels[i], x=find_max_label_length(labels))
 
         values = data[i]
         num_blocks = normal_dat[i]
@@ -243,33 +266,43 @@ def horiz_rows(labels, data, normal_dat, args, colors, doprint=True):
             # whereas the rest categories have only spaces.
             if j > 0:
                 len_label = len(label)
-                label = ' ' * len_label
-            if args.get('label_before'):
-                fmt = '{}{}'
+                label = " " * len_label
+            if args.get("label_before"):
+                fmt = "{}{}"
             else:
-                fmt = ' {}{}'
+                fmt = " {}{}"
 
-            if args['no_values']:
-                tail = args['suffix']
+            if args["no_values"]:
+                tail = args["suffix"]
             else:
-                tail = fmt.format(args['format'].format(values[j]), args['suffix'])
+                tail = fmt.format(args["format"].format(values[j]), args["suffix"])
 
             if colors:
                 color = colors[j]
             else:
                 color = None
 
-            if doprint and not args['vertical']:
+            if doprint and not args["vertical"]:
                 print(label, end="")
 
-            yield (values[j], int(num_blocks[j]), val_min, color, label, tail, not doprint and not args['vertical'])
+            yield (
+                values[j],
+                int(num_blocks[j]),
+                val_min,
+                color,
+                label,
+                tail,
+                not doprint and not args["vertical"],
+            )
 
-            if doprint and not args['vertical']:
+            if doprint and not args["vertical"]:
                 print(tail)
 
 
 # Prints a row of the horizontal graph.
-def print_row(value, num_blocks, val_min, color, label=False, tail=False, doprint=False):
+def print_row(
+    value, num_blocks, val_min, color, label=False, tail=False, doprint=False
+):
     """A method to print a row for a horizontal graphs.
 
     i.e:
@@ -277,26 +310,30 @@ def print_row(value, num_blocks, val_min, color, label=False, tail=False, doprin
     2: ▇▇▇ 3
     3: ▇▇▇▇ 4
     """
-    sys.stdout.write('\033[0m')  # no color
+    sys.stdout.write("\033[0m")  # no color
     if value == 0.0:
-        sys.stdout.write('\033[90m')  # dark gray
+        sys.stdout.write("\033[90m")  # dark gray
 
     if doprint:
         print(label, tail, " ", end="")
 
-    if (num_blocks < 1 and (value > val_min or value > 0)) or (doprint and value == 0.0):
+    if (num_blocks < 1 and (value > val_min or value > 0)) or (
+        doprint and value == 0.0
+    ):
         # Print something if it's not the smallest
         # and the normal value is less than one.
         sys.stdout.write(SM_TICK)
     else:
         if color:
-            sys.stdout.write('\033[{color}m'.format(color=color)) # Start to write colorized.
-            sys.stdout.write(f'\033[{color}m')  # Start to write colorized.
+            sys.stdout.write(
+                "\033[{color}m".format(color=color)
+            )  # Start to write colorized.
+            sys.stdout.write(f"\033[{color}m")  # Start to write colorized.
         for _ in range(num_blocks):
             sys.stdout.write(TICK)
 
     if color:
-        sys.stdout.write('\033[0m')  # Back to original.
+        sys.stdout.write("\033[0m")  # Back to original.
 
     if doprint:
         print()
@@ -308,12 +345,11 @@ def stacked_graph(labels, data, normal_data, len_categories, args, colors):
     val_min = find_min(data)
 
     for i in range(len(labels)):
-        if args['no_labels']:
+        if args["no_labels"]:
             # Hide the labels.
-            label = ''
+            label = ""
         else:
-            label = "{:<{x}}: ".format(labels[i],
-                                       x=find_max_label_length(labels))
+            label = "{:<{x}}: ".format(labels[i], x=find_max_label_length(labels))
 
         print(label, end="")
         values = data[i]
@@ -322,11 +358,11 @@ def stacked_graph(labels, data, normal_data, len_categories, args, colors):
         for j in range(len(values)):
             print_row(values[j], int(num_blocks[j]), val_min, colors[j])
 
-        tail = ' {}{}'.format(args['format'].format(sum(values)),
-                              args['suffix'])
+        tail = " {}{}".format(args["format"].format(sum(values)), args["suffix"])
         print(tail)
 
 
+# FIXME: globals for vertical, not ideal
 value_list, zipped_list, vertical_list, maxi = [], [], [], 0
 
 
@@ -348,7 +384,7 @@ def vertically(value, num_blocks, val_min, color, args):
         vertical_list.append(SM_TICK)
 
     # Zip_longest method in order to turn them vertically.
-    for row in zip_longest(*vertical_list, fillvalue='  '):
+    for row in zip_longest(*vertical_list, fillvalue=" "):
         zipped_list.append(row)
 
     counter, result_list = 0, []
@@ -359,8 +395,8 @@ def vertically(value, num_blocks, val_min, color, args):
         result_list.append(i)
         counter += 1
 
-        if maxi == args['width']:
-            if counter == (args['width']):
+        if maxi == args["width"]:
+            if counter == (args["width"]):
                 break
         else:
             if counter == maxi:
@@ -373,22 +409,24 @@ def vertically(value, num_blocks, val_min, color, args):
 def print_vertical(vertical_rows, labels, color, args):
     """Print the whole vertical graph."""
     if color:
-        sys.stdout.write('\033[{color}m'.format(color=color)) # Start to write colorized.
+        sys.stdout.write(
+            "\033[{color}m".format(color=color)
+        )  # Start to write colorized.
 
     for row in vertical_rows:
         print(*row)
 
-    sys.stdout.write('\033[0m')  # End of printing colored
+    sys.stdout.write("\033[0m")  # End of printing colored
 
-    print("-" * len(row) + "Values" + "-" * len(row))
-    # Print Values
-    for value in zip_longest(*value_list, fillvalue=' '):
-        print("  ".join(value))
+    if not args["no_values"]:
+        print("-" * len(row) + "Values" + "-" * len(row))
+        for value in zip_longest(*value_list, fillvalue=" "):
+            print("  ".join(value))
 
-    if args['no_labels'] == False:
+    if not args["no_labels"]:
         print("-" * len(row) + "Labels" + "-" * len(row))
         # Print Labels
-        for label in zip_longest(*labels, fillvalue=''):
+        for label in zip_longest(*labels, fillvalue=""):
             print("  ".join(label))
 
 
@@ -397,10 +435,9 @@ def chart(colors, data, args, labels):
     len_categories = len(data[0])
     if len_categories > 1:
         # Stacked graph
-        if args['stacked']:
-            normal_dat = normalize(data, args['width'])
-            stacked_graph(labels, data, normal_dat, len_categories,
-                          args, colors)
+        if args["stacked"]:
+            normal_dat = normalize(data, args["width"])
+            stacked_graph(labels, data, normal_dat, len_categories, args, colors)
             return
 
         if not colors:
@@ -408,44 +445,59 @@ def chart(colors, data, args, labels):
 
         # Multiple series graph with different scales
         # Normalization per category
-        if args['different_scale']:
+        if args["different_scale"]:
             for i in range(len_categories):
                 cat_data = []
                 for dat in data:
                     cat_data.append([dat[i]])
 
                 # Normalize data, handle negatives.
-                normal_cat_data = normalize(cat_data, args['width'])
+                normal_cat_data = normalize(cat_data, args["width"])
 
                 # Generate data for a row.
-                for row in horiz_rows(labels, cat_data, normal_cat_data,
-                                      args, [colors[i]]):
+                for row in horiz_rows(
+                    labels, cat_data, normal_cat_data, args, [colors[i]]
+                ):
                     # Print the row
-                    if not args['vertical']:
-                        print_row(*row)
+                    if args["vertical"]:
+                        # FIXME: passing args is getting complex
+                        vertic = vertically(row[0], row[1], row[2], row[3], args=args)
                     else:
-                        vertic = vertically(*row, args=args)
+                        print_row(*row)
 
-                # Vertical graph
-                if args['vertical']:
+                # The above gathers data for vertical and does not pritn
+                # the final print happens at once here
+                if args["vertical"]:
                     print_vertical(vertic, labels, colors[i], args)
 
                 print()
                 value_list.clear(), zipped_list.clear(), vertical_list.clear()
             return
 
+    if args["histogram"]:
+        if args["vertical"]:
+            print(">> Error: Vertical graph for Histogram" " is not supported yet.")
+            sys.exit(1)
+
+        for row in hist_rows(data, args, colors):
+            print_row(*row)
+        return
+
     # One category/Multiple series graph with same scale
     # All-together normalization
-    if not args['stacked']:
-        normal_dat = normalize(data, args['width'])
-        sys.stdout.write('\033[0m')  # no color
-        for row in horiz_rows(labels, data, normal_dat, args, colors, not args.get('label_before')):
-            if not args['vertical']:
+    if not args["stacked"]:
+        normal_dat = normalize(data, args["width"])
+        sys.stdout.write("\033[0m")  # no color
+        for row in horiz_rows(
+            labels, data, normal_dat, args, colors, not args.get("label_before")
+        ):
+            if not args["vertical"]:
                 print_row(*row)
             else:
-                vertic = vertically(*row, args=args)
+                # FIXME: passing args is getting complex
+                vertic = vertically(row[0], row[1], row[2], row[3], args=args)
 
-        if args['vertical'] and len_categories == 1:
+        if args["vertical"] and len_categories == 1:
             if colors:
                 color = colors[0]
             else:
@@ -474,23 +526,46 @@ def check_data(labels, data, args):
     colors = []
 
     # If user inserts colors, they should be as many as the categories.
-    if args['color'] is not None:
-        if len(args['color']) != len_categories:
-            print(">> Error: Color and category array sizes don't match")
-            sys.exit(1)
+    if args["color"] is not None:
+        # Decompose arguments for Windows
+        if os.name == "nt":
+            colorargs = re.findall(r"[a-z]+", args["color"][0])
+            if len(colorargs) != len_categories:
+                print(">> Error: Color and category array sizes don't match")
+            for color in colorargs:
+                if color not in AVAILABLE_COLORS:
+                    print(
+                        ">> Error: invalid color. choose from 'red', 'blue', 'green', 'magenta', 'yellow', 'black', 'cyan'"
+                    )
+                    sys.exit(2)
+        else:
+            if len(args["color"]) != len_categories:
+                print(">> Error: Color and category array sizes don't match")
+            for color in args["color"]:
+                if color not in AVAILABLE_COLORS:
+                    print(
+                        ">> Error: invalid color. choose from 'red', 'blue', 'green', 'magenta', 'yellow', 'black', 'cyan'"
+                    )
+                    sys.exit(2)
 
-        for color in args['color']:
-            colors.append(AVAILABLE_COLORS.get(color))
+        if os.name == "nt":
+            for color in colorargs:
+                colors.append(AVAILABLE_COLORS.get(color))
+        else:
+            for color in args["color"]:
+                colors.append(AVAILABLE_COLORS.get(color))
 
     # Vertical graph for multiple series of same scale is not supported yet.
-    if args['vertical'] and len_categories > 1 and not args['different_scale']:
-        print(">> Error: Vertical graph for multiple series of same "
-              "scale is not supported yet.")
+    if args["vertical"] and len_categories > 1 and not args["different_scale"]:
+        print(
+            ">> Error: Vertical graph for multiple series of same "
+            "scale is not supported yet."
+        )
         sys.exit(1)
 
     # If user hasn't inserted colors, pick the first n colors
     # from the dict (n = number of categories).
-    if args['stacked'] and not colors:
+    if args["stacked"] and not colors:
         colors = [v for v in list(AVAILABLE_COLORS.values())[:len_categories]]
 
     return colors
@@ -501,14 +576,16 @@ def print_categories(categories, colors):
        the graph."""
     for i in range(len(categories)):
         if colors:
-            sys.stdout.write('\033[{color_i}m'.format(color_i=colors[i])) # Start to write colorized.
-            sys.stdout.write(f'\033[{colors[i]}m')  # Start to write colorized.
+            sys.stdout.write(
+                "\033[{color_i}m".format(color_i=colors[i])
+            )  # Start to write colorized.
+            sys.stdout.write(f"\033[{colors[i]}m")  # Start to write colorized.
 
-        sys.stdout.write(TICK + ' ' + categories[i] + '  ')
+        sys.stdout.write(TICK + " " + categories[i] + "  ")
         if colors:
-            sys.stdout.write('\033[0m')  # Back to original.
+            sys.stdout.write("\033[0m")  # Back to original.
 
-    print('\n\n')
+    print("\n\n")
 
 
 def read_data(args):
@@ -522,15 +599,15 @@ def read_data(args):
        labels = ['2001', '2002', '2003', ...]
        categories = ['boys', 'girls']
        data = [ [20.4, 40.5], [30.7, 100.0], ...]"""
-    filename = args['filename']
-    stdin = filename == '-'
+    filename = args["filename"]
+    stdin = filename == "-"
 
-    if args['verbose']:
-        print('>> Reading data from {src}'.format(src=( "stdin" if stdin else filename )))
+    if args["verbose"]:
+        print(">> Reading data from {src}".format(src=("stdin" if stdin else filename)))
 
-    print('')
-    if args['title']:
-        print('# ' + args['title'] + '\n')
+    print("")
+    if args["title"]:
+        print("# " + args["title"] + "\n")
 
     categories, labels, data, colors = ([] for i in range(4))
 
@@ -539,14 +616,14 @@ def read_data(args):
         for line in f:
             line = line.strip()
             if line:
-                if not line.startswith('#'):
+                if not line.startswith("#"):
                     if line.find(DELIM) > 0:
                         cols = line.split(DELIM)
                     else:
                         cols = line.split()
 
                     # Line contains categories.
-                    if line.startswith('@'):
+                    if line.startswith("@"):
                         cols[0] = cols[0].replace("@ ", "")
                         categories = cols
 
@@ -574,10 +651,10 @@ def read_data(args):
 
 def calendar_heatmap(data, labels, args):
     """Print a calendar heatmap."""
-    if args['color']:
-        colornum = AVAILABLE_COLORS.get(args['color'][0])
+    if args["color"]:
+        colornum = AVAILABLE_COLORS.get(args["color"][0])
     else:
-        colornum = AVAILABLE_COLORS.get('blue')
+        colornum = AVAILABLE_COLORS.get("blue")
 
     dt_dict = {}
     for i in range(len(labels)):
@@ -591,16 +668,15 @@ def calendar_heatmap(data, labels, args):
     tick_3 = "▓"
     tick_4 = "█"
 
-    if args['custom_tick']:
-        tick_1 = tick_2 = tick_3 = tick_4 = args['custom_tick']
+    if args["custom_tick"]:
+        tick_1 = tick_2 = tick_3 = tick_4 = args["custom_tick"]
 
     # check if start day set, otherwise use one year ago
-    if args['start_dt']:
-        start_dt = datetime.strptime(args['start_dt'], '%Y-%m-%d')
+    if args["start_dt"]:
+        start_dt = datetime.strptime(args["start_dt"], "%Y-%m-%d")
     else:
         start = datetime.now()
-        start_dt = datetime(year=start.year - 1, month=start.month,
-                            day=start.day)
+        start_dt = datetime(year=start.year - 1, month=start.month, day=start.day)
 
     # modify start date to be a Monday, subtract weekday() from day
     start_dt = start_dt - timedelta(start_dt.weekday())
@@ -609,16 +685,17 @@ def calendar_heatmap(data, labels, args):
     # top legend for months
     sys.stdout.write("     ")
     for month in range(13):
-        month_dt = datetime(year=start_dt.year, month=start_dt.month, day=1) + \
-                   timedelta(days=month * 31)
+        month_dt = datetime(
+            year=start_dt.year, month=start_dt.month, day=1
+        ) + timedelta(days=month * 31)
         sys.stdout.write(month_dt.strftime("%b") + " ")
-        if args['custom_tick']:  # assume custom tick is emoji which is one wider
+        if args["custom_tick"]:  # assume custom tick is emoji which is one wider
             sys.stdout.write(" ")
 
-    sys.stdout.write('\n')
+    sys.stdout.write("\n")
 
     for day in range(7):
-        sys.stdout.write(DAYS[day] + ': ')
+        sys.stdout.write(DAYS[day] + ": ")
         for week in range(53):
             day_ = start_dt + timedelta(days=day + week * 7)
             day_str = day_.strftime("%Y-%m-%d")
@@ -632,21 +709,21 @@ def calendar_heatmap(data, labels, args):
                     tick = tick_2
                 # show nothing if value is zero
                 elif dt_dict[day_str] == 0.0:
-                    tick = ' '
+                    tick = " "
                 # show values for less than 0.25
                 else:
                     tick = tick_1
             else:
-                tick = ' '
+                tick = " "
 
             if colornum:
-                sys.stdout.write('\033[{colornum}m'.format(colornum=colornum))
+                sys.stdout.write("\033[{colornum}m".format(colornum=colornum))
 
             sys.stdout.write(tick)
             if colornum:
-                sys.stdout.write('\033[0m')
+                sys.stdout.write("\033[0m")
 
-        sys.stdout.write('\n')
+        sys.stdout.write("\n")
 
 
 if __name__ == "__main__":
